# Toai

Toai provides convenient classes and functions for machine learning, data science and data analysis.

## Install

```python
pip install toai
```

## Usage

- Import most useful default imports (useful for notebooks). This will give you access to `np` for NumPy, `pd` for Pandas, `sns` for Seaborn and many more.

  ```python
  from toai.imports import *
  ```

- Import functions from a specific submodule. This will import RMSE and error rate metrics from the metrics submodule.

  ```python
  from toai.metrics import rmse, error_rate
  ```
